OngoingAsyncAction

Struct OngoingAsyncAction 

pub struct OngoingAsyncAction<T> {
    strong: Rc<AsyncAction<T>>,
}
Helper type to keep track of ongoing async actions that can succeed in different functions.

This type can only have one strong reference and many weak references.

The strong reference should be dropped in the first function where the action succeeds. Then other functions can drop the weak references when they can’t be upgraded.

Fields

strong: Rc<AsyncAction<T>>

Implementations

Source

impl<T> OngoingAsyncAction<T>

pub(crate) fn set(value: T) -> (Self, WeakOngoingAsyncAction<T>)

Create a new async action that sets the given value.

Returns both a strong and a weak reference.

pub(crate) fn remove() -> (Self, WeakOngoingAsyncAction<T>)

Create a new async action that removes a value.

Returns both a strong and a weak reference.

pub(crate) fn as_value(&self) -> Option<&T>

Get the inner value, if any.