pub struct OngoingAsyncAction<T> {
strong: Rc<AsyncAction<T>>,
}Expand description
Helper type to keep track of ongoing async actions that can succeed in different functions.
This type can only have one strong reference and many weak references.
The strong reference should be dropped in the first function where the action succeeds. Then other functions can drop the weak references when they can’t be upgraded.
Fields
strong: Rc<AsyncAction<T>>Implementations
Sourceimpl<T> OngoingAsyncAction<T>
impl<T> OngoingAsyncAction<T>
Sourcepub(crate) fn set(value: T) -> (Self, WeakOngoingAsyncAction<T>)
pub(crate) fn set(value: T) -> (Self, WeakOngoingAsyncAction<T>)
Create a new async action that sets the given value.
Returns both a strong and a weak reference.
Sourcepub(crate) fn remove() -> (Self, WeakOngoingAsyncAction<T>)
pub(crate) fn remove() -> (Self, WeakOngoingAsyncAction<T>)
Create a new async action that removes a value.
Returns both a strong and a weak reference.